@@ -6,7 +6,7 @@
 // This is the header file for the Person agent.  It defines the 
 // instance variables and everything else the Person needs to work
 // in the world.
-#import <swarmobject/SwarmObject.h>
+#import <objectbase/SwarmObject.h>
 #import <collections/String.h>
 
 // define a type to help index conversation subjects
