@@ -5,8 +5,7 @@
 
 // This is the method definitions file for the Person agents.
 
-// include simtools so we can use the random number library
-#import <simtools.h>
+#import <random.h>
 // include person header so that everything will be defined
 #import "Person.h"
 
