@@ -4,6 +4,7 @@
 // See file LICENSE for details and terms of copying.
 
 #import "PplObserverSwarm.h"
+#import <simtoolsgui.h>
 
 // implementation of sample graphical interface for models.
 @implementation PplObserverSwarm
@@ -54,7 +55,7 @@
   CREATE_PROBE_DISPLAY (self);
 
   // set the control panel state
-  [controlPanel waitForControlEvent];
+  [actionCache waitForControlEvent];
   // test to see if the "quit" button was hit
   if ([controlPanel getState] == ControlStateQuit)
     return self;
