@@ -3,34 +3,36 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <objectbase.h>
-#import <simtools/GUISwarm.h>
+#import <simtoolsgui/GUISwarm.h>
+#import <simtoolsgui.h>
+#import <gui.h>
 #import "PplModelSwarm.h"
 
 // Sample graphical interface swarm for models.
-@interface PplObserverSwarm : GUISwarm {
+@interface PplObserverSwarm: GUISwarm
+{
   int displayFrequency;
 
   id displayActions;
   id displaySchedule;
 
   // add the modelswarm to the observer swarm
-  PplModelSwarm * pplModelSwarm;
+  PplModelSwarm *pplModelSwarm;
   // add the counter to the observer swarm
-  Counter * observedCounter;
+  Counter *observedCounter;
   // add the numberPplStillTalking graph to obs swarm
-  BLTGraph * pplLeftGraph;
-  GraphElement * numberLeft;
-  ActiveGraph  * pplLeftGrapher;
+  id <Graph> pplLeftGraph;
+  id <GraphElement> numberLeft;
+  id <ActiveGraph> pplLeftGrapher;
 }
 
-+createBegin: (id) aZone;
--createEnd;
--buildObjects;
--buildActions;
--activateIn: (id) swarmContext;
++ createBegin: aZone;
+- createEnd;
+- buildObjects;
+- buildActions;
+- activateIn: swarmContext;
 
 // checks to see if everybody's done talking
--checkToStop;
+- checkToStop;
 
 @end
