@@ -17,12 +17,15 @@
   26-SEP-1996
 */
 
+#import <space/Discrete2d.h>
 #import <space.h>
 
 @interface DiscreteToroid: Discrete2d 
-
--(int) wrapXCoord: (int) inX;
--(int) wrapYCoord: (int) inY;
-
+- (int)wrapXCoord: (int)inX;
+- (int)wrapYCoord: (int)inY;
 @end
 
+@protocol DiscreteToroid <Discrete2d>
+- (int)wrapXCoord: (int)inX;
+- (int)wrapYCoord: (int)inY;
+@end
