@@ -15,11 +15,9 @@
   North, East, South, West (in that order).
 */
 
-#import <objectbase.h>
+#import <objectbase/SwarmObject.h>
 #import "neighbor.h"
 
-
-
 @interface VNneighbor: SwarmObject
 
 /* The -next and -previous methods each rotate the
@@ -29,8 +27,8 @@
 
   The -random method picks a random (VN) neighbor (with 
   uniform probability function) and returns it.  */
--(neighbor_t) next: (neighbor_t) inNeighbor;
--(neighbor_t) previous: (neighbor_t) inNeighbor;
--(neighbor_t) random;
+- (neighbor_t)next: (neighbor_t)inNeighbor;
+- (neighbor_t)previous: (neighbor_t)inNeighbor;
+- (neighbor_t)random;
 
 @end
