@@ -3,18 +3,19 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <swarmobject/SwarmObject.h>
+#import <objectbase/SwarmObject.h>
 
 // This is just a sample agent: real models need real agents.
 
-@interface Counter: SwarmObject {
+@interface Counter: SwarmObject
+{
   int value;
   int incr;
 }
 
--step;
--setIncr: (int) n;
--print;
+- step;
+- setIncr: (int)n;
+- print;
 
 @end
 
