@@ -11,15 +11,18 @@
 #import "TemplateObserverSwarm.h"
 
 int
-main(int argc, char ** argv) {
-  TemplateObserverSwarm * observerSwarm;
+main (int argc, const char **argv)
+{
+  TemplateObserverSwarm *observerSwarm;
 
-  initSwarm(argc, argv);
+  initSwarm (argc, argv);
 
+#if 0
   [globalTkInterp eval: "bitmap define testmap {{16 16} {
    0x00, 0x00, 0x00, 0x00, 0x04, 0x80, 0x08, 0x40, 0x90, 0x27, 0x60, 0x18,
    0x60, 0x18, 0x90, 0x24, 0x10, 0x23, 0x10, 0x23, 0x90, 0x24, 0x60, 0x18,
    0x60, 0x18, 0x90, 0x27, 0x08, 0x40, 0x04, 0x80}}"] ;
+#endif
 
   observerSwarm = [TemplateObserverSwarm create: globalZone];
   [observerSwarm buildObjects];
